/**
 * An alert used to share important information
 * */
export default {
  title: 'Components/Alert',
  tags: ['autodocs'],
  argTypes: {
    type: {
      control: 'select',
      options: ['Error', 'Warning', 'Information', 'Success'],
      mapping: {
        Error: 'rpf-alert--error',
        Warning: 'rpf-alert--warning',
        Information: 'rpf-alert--information',
        Success: 'rpf-alert--success',
      },
    },
    close: {
      control: 'boolean',
    },
  },
  args: {
    type: '',
    close: false,
  },
}

const ButtonTemplate = ({ close, type }) => {
  const className = ['rpf-alert', type].join(' ')
  return `<div class="${className}">
    <span class="rpf-alert__icon material-symbols-sharp"></span>
    <div class="rpf-alert__body">
      <p class="rpf-alert__title">This is an example alert that a user might see</p>
      <p>
        This is the body of text that could be available to the user to see if there was a longer message for example if something has gone wrong or maybe just a wordy explanation of something that has gone right, the possibilities are endless.
      </p>
      <div class="rpf-alert__actions">
        <button class="rpf-button rpf-button--sm rpf-button--tertiary">Option One</button>
        <button class="rpf-button rpf-button--sm rpf-button--tertiary">Option Two</button>
      </div>
    </div>
    ${close ? `<button class="rpf-alert__close material-symbols-sharp">close</button>` : ''}
  </div>`
}

export const Error = ButtonTemplate.bind({})
Error.args = {
  type: 'Error',
}

export const Warning = ButtonTemplate.bind({})
Warning.args = {
  type: 'Warning',
}

export const Information = ButtonTemplate.bind({})
Information.args = {
  type: 'Information',
}

export const Success = ButtonTemplate.bind({})
Success.args = {
  type: 'Success',
}
