/**
 * The standard button to be used everywhere
 * */
export default {
  title: 'Components/Button',
  tags: ['autodocs'],
  argTypes: {
    text: {
      control: 'text',
    },
    disabled: {
      control: 'boolean',
    },
    type: {
      control: 'select',
      options: ['primary', 'secondary', 'tertiary'],
      mapping: {
        primary: '',
        secondary: 'rpf-button--secondary',
        tertiary: 'rpf-button--tertiary',
        danger: 'rpf-button--danger',
      },
    },
    variant: {
      control: 'select',
      options: ['default', 'danger'],
      mapping: {
        default: '',
        danger: 'rpf-button--danger',
      },
    },
    size: {
      control: 'select',
      options: ['default', 'small'],
      mapping: {
        default: '',
        small: 'rpf-button--sm',
      },
    },
    icon: {
      control: 'text',
      description: 'Icon names can be found [here](https://fonts.google.com/icons)',
    },
    iconPosition: {
      control: 'select',
      options: ['left', 'right'],
    },
    iconOnly: {
      control: 'boolean',
    },
    fullWidth: {
      control: 'boolean',
    },
  },
  args: {
    text: 'Button text',
    type: 'primary',
    variant: 'default',
    size: 'default',
    icon: '',
    iconOnly: false,
    iconPosition: 'left',
    fullWidth: false,
    disabled: false,
  },
}

const ButtonTemplate = ({ text, disabled, fullWidth, iconPosition, iconOnly, icon, size, type, variant }) => {
  const className = [
    'rpf-button',
    type,
    variant,
    size,
    iconOnly && 'rpf-button--icon-only',
    fullWidth && 'rpf-button--full-width',
  ]
    .filter((n) => n)
    .join(' ')

  const iconSpan = (icon) => (icon ? `<span class="rpf-button__icon material-symbols-sharp">${icon}</span>` : '')

  return `
  <button class="${className}"${disabled ? ' disabled' : ''}>
    ${(iconPosition === 'left' && icon != '') || iconOnly ? iconSpan(icon) : ''}
    ${iconOnly ? '' : text}
    ${iconPosition === 'right' && !iconOnly && icon != '' ? iconSpan(icon) : ''}
  </button>`
}

const LinkTemplate = ({ text, fullWidth, iconPosition, iconOnly, icon, size, type, variant, disabled }) => {
  const className = [
    'rpf-button',
    type,
    variant,
    size,
    iconOnly && 'rpf-button--icon-only',
    fullWidth && 'rpf-button--full-width',
    disabled && 'rpf-button--disabled',
  ]
    .filter((n) => n)
    .join(' ')

  const iconSpan = (icon) => (icon ? `<span class="rpf-button__icon material-symbols-sharp">${icon}</span>` : '')
  return `
  <a href="#" class="${className}">
    ${(iconPosition === 'left' && icon != '') || iconOnly ? iconSpan(icon) : ''}
    ${iconOnly ? '' : text}
    ${iconPosition === 'right' && !iconOnly && icon != '' ? iconSpan(icon) : ''}
  </a>
  `
}

export const Primary = ButtonTemplate.bind({})
Primary.args = {}

export const LinkTest = ButtonTemplate.bind({})
LinkTest.args = {
  disabled: true,
}

export const Secondary = ButtonTemplate.bind({})
Secondary.args = {
  type: 'secondary',
}

export const Tertiary = ButtonTemplate.bind({})
Tertiary.args = {
  type: 'tertiary',
}

export const Danger = ButtonTemplate.bind({})
Danger.args = {
  type: 'danger',
}

export const Disabled = ButtonTemplate.bind({})
Disabled.args = {
  disabled: true,
}

export const Small = ButtonTemplate.bind({})
Small.args = {
  size: 'small',
}

export const TextAndIcon = ButtonTemplate.bind({})
TextAndIcon.args = {
  icon: 'sentiment_satisfied',
}

export const IconOnly = ButtonTemplate.bind({})
IconOnly.args = {
  icon: 'sentiment_satisfied',
  iconOnly: true,
}

export const FullWidth = ButtonTemplate.bind({})
FullWidth.args = {
  fullWidth: true,
}

export const Link = LinkTemplate.bind({})
Link.args = {}

export const DisabledLink = LinkTemplate.bind({})
DisabledLink.args = {
  disabled: true,
}
